@@ -1,10 +1,10 @@
 import enum
-from dataclasses import dataclass
-from serde import serialize, deserialize
-from serde.json import to_json, from_json
 
 import imported
 
+from serde import serde
+from serde.json import from_json, to_json
+
 
 class Nested(enum.Enum):
     S = 'foo'
@@ -23,15 +23,13 @@ class IE(enum.IntEnum):
     V2 = enum.auto()
 
 
-@deserialize
-@serialize
-@dataclass
+@serde
 class Foo:
     v0: IE
     v1: IE = IE.V1  # Default enum value.
     v2: E = E.S
     v3: imported.ImportedEnum = imported.ImportedEnum.V3  # Use enum imported from other module.
-    # v3: E = E.N  # Sorry nested is not yet supported.
+    v4: E = E.N  # Use nested enum.
 
 
 if __name__ == "__main__":
@@ -43,5 +41,7 @@ if __name__ == "__main__":
     print(f)
     s = to_json(f)
 
-    # Non Enum values cause type mismatch error.
-    # s = to_json(Foo(0))
+    # You can also pass an enum-compabitle value (in this case True for E.B).
+    # Caveat: Foo takes any value IE accepts. e.g., Foo(True) is also valid.
+    s = to_json(Foo(3))
+    print(s)
