@@ -4,27 +4,25 @@ jsonfile.py
 Make an http request to JSON WebAPI.
 
 Usage:
-    $ pipenv install
-    $ pipenv run jsonfile.py
+    $ poetry install
+    $ poetry run python jsonfile.py
 """
+from typing import List, Optional
+
 import requests
 
-from typing import List, Optional
-from dataclasses import dataclass
-from serde import deserialize
+from serde import serde
 from serde.json import from_json
 
 
-@deserialize
-@dataclass
+@serde
 class Slide:
     title: str
     type: str
     items: Optional[List[str]]
 
 
-@deserialize
-@dataclass
+@serde
 class Slideshow:
     author: str
     date: str
@@ -32,8 +30,7 @@ class Slideshow:
     title: str
 
 
-@deserialize
-@dataclass
+@serde
 class Data:
     slideshow: Slideshow
 
