@@ -4,31 +4,29 @@ skip.py
 Example usage of skip and skip_if attributes.
 
 Usage:
-    $ pipenv install
-    $ pipenv run skip.py
+    $ poetry install
+    $ poetry run python skip.py
 """
 
-from typing import List, Dict
-from dataclasses import dataclass, field
-from serde import serialize, deserialize
+from typing import Dict, List
+
+from serde import field, serde
 from serde.json import to_json
 
 
-@serialize
-@dataclass
+@serde
 class Resource:
     name: str
     hash: str
-    metadata: Dict[str, str] = field(default_factory=dict, metadata={'serde_skip': True})
+    metadata: Dict[str, str] = field(default_factory=dict, skip=True)
 
 
-@deserialize
-@serialize
-@dataclass
+@serde
 class World:
     player: str
-    enemies: List[str] = field(default_factory=list, metadata={'serde_skip_if_false': True})
-    buddy: str = field(default='', metadata={'serde_skip_if': lambda v: v == 'Pikachu'})
+    enemies: List[str] = field(default_factory=list, skip_if_false=True)
+    buddy: str = field(default='', skip_if=lambda v: v == 'Pikachu')
+    town: str = field(default='Masara Town', skip_if_default=True)
 
 
 def main():
@@ -38,10 +36,12 @@ def main():
     ]
     print(to_json(resources))
 
+    # "buddy" and "town" field will be omitted
     world = World('satoshi', ['Rattata', 'Pidgey'], 'Pikachu')
     print(to_json(world))
 
-    world = World('green', [], 'Charmander')
+    # "enemies" field will be omitted
+    world = World('green', [], 'Charmander', 'Black City')
     print(to_json(world))
 
 
