@@ -4,39 +4,35 @@ tomlfile.py
 Read Pipenv Pipfile by pyserde.
 
 Usage:
-    $ pipenv install
-    $ pipenv run tomlfile.py
+    $ poetry install
+    $ poetry run python tomlfile.py
 """
-from typing import List, Dict, Optional, Union
-from dataclasses import dataclass
-from serde import deserialize
+from typing import Dict, List, Optional, Union
+
+from serde import serde
 from serde.toml import from_toml
 
 
-@deserialize
-@dataclass
+@serde
 class Source:
     url: str
     verify_ssl: bool
     name: str
 
 
-@deserialize
-@dataclass
+@serde
 class Requires:
     python_version: str
 
 
-@deserialize
-@dataclass
+@serde
 class Package:
     path: Optional[str] = None
     version: Optional[str] = None
     editable: Optional[bool] = False
 
 
-@deserialize
-@dataclass
+@serde
 class Pipfile:
     source: List[Source]
     requires: Optional[Requires]
