@@ -4,41 +4,37 @@ yamlfile.py
 Read swagger echo example yaml.
 
 Usage:
-    $ pipenv install
-    $ pipenv run yamlfile.py
+    $ poetry install
+    $ poetry run python yamlfile.py
 """
-from typing import List, Dict, Optional, Union
-from dataclasses import dataclass
-from serde import deserialize
+from typing import Dict, List, Optional, Union
+
+from serde import serde
 from serde.yaml import from_yaml
 
 
-@deserialize(rename_all='camelcase')
-@dataclass
+@serde(rename_all='camelcase')
 class Info:
     title: str
     description: str
     version: str
 
 
-@deserialize(rename_all='camelcase')
-@dataclass
+@serde(rename_all='camelcase')
 class Parameter:
     name: str
     # not yet supported.
-    # infield: str = field(metadata={'serde_rename': 'in'})
+    # infield: str = field(rename='in')
     type: str
     required: bool
 
 
-@deserialize(rename_all='camelcase')
-@dataclass
+@serde(rename_all='camelcase')
 class Response:
     description: str
 
 
-@deserialize(rename_all='camelcase')
-@dataclass
+@serde(rename_all='camelcase')
 class Path:
     description: str
     operation_id: str
@@ -46,22 +42,19 @@ class Path:
     responses: Dict[Union[str, int], Response]
 
 
-@deserialize(rename_all='camelcase')
-@dataclass
+@serde(rename_all='camelcase')
 class Prop:
     type: str
     format: Optional[str]
 
 
-@deserialize(rename_all='camelcase')
-@dataclass
+@serde(rename_all='camelcase')
 class Definition:
     required: Optional[List[str]]
     properties: Dict[str, Prop]
 
 
-@deserialize(rename_all='camelcase')
-@dataclass
+@serde(rename_all='camelcase')
 class Swagger:
     swagger: int
     info: Info
