@@ -1,12 +1,14 @@
 """
 pyserde inspection tool.
 
-USAGE:
+#### Usage
 
+```
 $ python -m serde.inspect <PATH> <NAME>
 
  PATH  Python script path.
  NAME  Pyserde class name.
+```
 
 """
 import argparse
@@ -16,31 +18,40 @@ import os
 import sys
 from typing import Type
 
-from .core import HIDDEN_NAME, init, logger
+from .core import SERDE_SCOPE, SerdeScope, init, logger
 
 init(True)
 
 
-def inspect(cls: Type) -> str:
+def inspect(cls: Type) -> None:
     """
     Inspect a pyserde class.
     """
-    hidden = getattr(cls, HIDDEN_NAME, None)
-    return '\n'.join(hidden.code.values())
+    scope: SerdeScope = getattr(cls, SERDE_SCOPE, {})
+    print(scope)
 
 
 def main(arg):
+    """
+    Main entrypoint of `serde.inspect`.
+    """
     if arg.verbose:
         logging.basicConfig(level=logging.DEBUG)
+
+    try:
+        import black
+
+        assert black
+    except ImportError:
+        logger.warning(('Tips: Installing "black" makes the output prettier! Try this command:\n' 'pip install back'))
+
     dir = os.path.dirname(arg.path)
     mod = os.path.basename(arg.path)[:-3]
-    print(f'Loading {mod}.{arg.name} from {dir}.')
+    print(f'Loading {mod}.{arg.name} from {dir}/{mod}.py')
     sys.path.append(dir)
     pkg = importlib.import_module(mod)
     cls = getattr(pkg, arg.name)
-    print(inspect(cls))
-    print('----------------------------------')
-    print(f"serde_scope: {getattr(cls, '__serde_scope__')}")
+    inspect(cls)
 
 
 parser = argparse.ArgumentParser(description='pyserde-inspect')
